==> todotask2.0.1.zip: todotask2/app/views/common/header.inc.php <==
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<?php
if (isset($this)) {
	$cTITLE = $this->title;
	$group_no = $this->group_no;
	$group_name = $this->group_name;
	$loginuser = $this->user_name;
	$grpmail_flg = $this->grpmail_flg;
	$mbMemberFlg = $this->memLv;
	$cPrototypeFlg = $this->protype_flg;
	$cInputDefFlg = $this->definput_flg;
	$refresh_tag = $this->refresh_tag;
}


?>
<html lang="ja"><head>
<?php echo $refresh_tag; ?>
<meta http-equiv="Pragma" content="no-cache">
<meta http-equiv="Content-Type" content="text/html; charset=<?php echo PAGE_CHARSET; ?>">
<meta http-equiv="Content-Style-Type" content="text/css">
<meta http-equiv="Content-Script-Type" content="text/javascript">
<meta http-equiv="Imagetoolbar" content="no">
<link rel="SHORTCUT ICON" href="<?php echo ROOT_URL; ?>favicon.ico">
<link rel="start" href="<?php echo START_PAGE; ?>" title="<?php echo START_TITLE; ?>">
<link rel="stylesheet" href="<?php echo ROOT_URL; ?>stylesheets/formatter.css" type="text/css" media="all">
<link rel="stylesheet" href="<?php echo ROOT_URL; ?>stylesheets/tag.css" type="text/css" media="all">
<meta name="keywords" content="<?php echo $cTITLE; ?>">
<?php
// Google Webmaster　toolを使用する
if (GOOGLE_WEBMASTER_CD!="") {
?>
<meta name="verify-v1" content="<?php echo GOOGLE_WEBMASTER_CD; ?>" />
<?php
}

// prototype.js を読み込む画面の場合は
if ($cPrototypeFlg == "1") {
?>
<script src="<?php echo ROOT_URL; ?>javascripts/prototype.js" type="text/javascript" Language="JavaScript"></script>
<script src="<?php echo ROOT_URL; ?>javascripts/ajaxedit.js" type="text/javascript" Language="JavaScript"></script>
<?php
}
// inputDefault.js を読み込む画面の場合は
if ($cInputDefFlg == "1") {
?>
<script src="<?php echo ROOT_URL; ?>javascripts/inputDefault.js" type="text/javascript" Language="JavaScript"></script>
<?php
}
?>
<title><?php echo $cTITLE; ?></title>
</head>

<body>
<a name="page_top"></a>
<div id="head">
<table border="0" cellspacing="0" cellpadding="0" width="100%">
  <tr>
    <td width="400" nowrap valign="bottom">
		<a href="./index.php"><img border="0" src="./images/topbanner.gif" alt="トドタスク" width="360" height="60" border="0"></a>
	</td>
    <td><br></td>
    <td align="right" class="grpheader" nowrap><a href="tasklist.php?group_no=<?php echo $group_no; ?>"><?php echo $group_name; ?></a><br></td>
    <td width="100" valign="bottom" align="right" class="notice"></td>
  </tr>
</table>
</div>
<div id="headmenu">
<?php
	require_once(TODOTASK_VIEW_DIR.'/common/loginbar.inc.php');
?>
</div>
<table border="0"><tr><td id="main" height="100%">
<div>
<!--img src="./images/blank.png" align="right" width="0" style="float:left;width:0px;height:580px;"-->
<?php
//プラグイン読み込み
?>

==> todotask2.0.2.zip: todotask2/app/views/common/header.inc.php <==
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<?php
if (isset($this)) {
	$cTITLE = $this->title;
	$group_no = $this->group_no;
	$group_name = $this->group_name;
	$loginuser = $this->user_name;
	$grpmail_flg = $this->grpmail_flg;
	$mbMemberFlg = $this->memLv;
	$cPrototypeFlg = $this->protype_flg;
	$cInputDefFlg = $this->definput_flg;
	$cCalendarJs = $this->calendarjs_flg;
	$refresh_tag = $this->refresh_tag;
}


?>
<html lang="ja"><head>
<?php echo $refresh_tag; ?>
<meta http-equiv="Pragma" content="no-cache">
<meta http-equiv="Content-Type" content="text/html; charset=<?php echo PAGE_CHARSET; ?>">
<meta http-equiv="Content-Style-Type" content="text/css">
<meta http-equiv="Content-Script-Type" content="text/javascript">
<meta http-equiv="Imagetoolbar" content="no">
<link rel="SHORTCUT ICON" href="<?php echo ROOT_URL; ?>favicon.ico">
<link rel="start" href="<?php echo START_PAGE; ?>" title="<?php echo START_TITLE; ?>">
<link rel="stylesheet" href="<?php echo ROOT_URL; ?>stylesheets/formatter.css" type="text/css" media="all">
<link rel="stylesheet" href="<?php echo ROOT_URL; ?>stylesheets/tag.css" type="text/css" media="all">
<meta name="keywords" content="<?php echo $cTITLE; ?>">
<?php
// Google Webmaster　toolを使用する
if (GOOGLE_WEBMASTER_CD!="") {
?>
<meta name="verify-v1" content="<?php echo GOOGLE_WEBMASTER_CD; ?>" />
<?php
}

// prototype.js を読み込む画面の場合は
if ($cPrototypeFlg == "1") {
?>
<script src="<?php echo ROOT_URL; ?>javascripts/prototype.js" type="text/javascript" Language="JavaScript"></script>
<script src="<?php echo ROOT_URL; ?>javascripts/ajaxedit.js" type="text/javascript" Language="JavaScript"></script>
<?php
}
// inputDefault.js を読み込む画面の場合は
if ($cInputDefFlg == "1") {
?>
<script src="<?php echo ROOT_URL; ?>javascripts/inputDefault.js" type="text/javascript" Language="JavaScript"></script>
<?php
}
// jkl-calendar.js　カレンダー入力補助クラス
if ($cCalendarJs == "1") {
?>
<script src="<?php echo ROOT_URL; ?>javascripts/jkl-calendar.js" type="text/javascript" Language="JavaScript" charset="Shift_JIS"></script>
<?php
}
?>
<title><?php echo $cTITLE; ?></title>
</head>

<body>
<a name="page_top"></a>
<div id="head">
<table border="0" cellspacing="0" cellpadding="0" width="100%">
  <tr>
    <td width="400" nowrap valign="bottom">
		<a href="./index.php"><img border="0" src="./images/topbanner.gif" alt="トドタスク" width="360" height="60" border="0"></a>
	</td>
    <td><br></td>
    <td align="right" class="grpheader" nowrap><a href="tasklist.php?group_no=<?php echo $group_no; ?>"><?php echo $group_name; ?></a><br></td>
    <td width="100" valign="bottom" align="right" class="notice"></td>
  </tr>
</table>
</div>
<div id="headmenu">
<?php
	require_once(TODOTASK_VIEW_DIR.'/common/loginbar.inc.php');
?>
</div>
<table border="0"><tr><td id="main" height="100%">
<div>
<!--img src="./images/blank.png" align="right" width="0" style="float:left;width:0px;height:580px;"-->
<?php
//プラグイン読み込み
?>
